@@ -74,7 +74,7 @@ DeclarationPointer ExpressionVisitor::processVariable(VariableIdentifierAst* var
         ///TODO: why doesn't m_currentContext->findDeclarations() work?
         ///      evaluate if the stuff below is fast enough (faster?) than findDeclarations()
         ///see r1028306
-        foreach(const DUContext::Import &import, m_currentContext->importedParentContexts() ) {
+        for(const DUContext::Import &import : m_currentContext->importedParentContexts() ) {
             if ( !import.isDirect() || import.position > position ) {
                 continue;
             }
@@ -90,7 +90,7 @@ DeclarationPointer ExpressionVisitor::processVariable(VariableIdentifierAst* var
     }
     if (!ret) {
         //look for a superglobal variable
-        foreach(Declaration* dec, m_currentContext->topContext()->findDeclarations(identifier, position)) {
+        for(Declaration* dec : m_currentContext->topContext()->findDeclarations(identifier, position)) {
             VariableDeclaration* varDec = dynamic_cast<VariableDeclaration*>(dec);
             if (varDec && varDec->isSuperglobal()) {
                 ret = dec;
@@ -110,7 +110,7 @@ DeclarationPointer ExpressionVisitor::processVariable(VariableIdentifierAst* var
             usingDeclaration(variable, ret);
         }
     }
-    ifDebug(qCDebug(DUCHAIN) << "found declaration:" << (ret ? ret->toString() : QString("no declaration found"));)
+    ifDebug(qCDebug(DUCHAIN) << "found declaration:" << (ret ? ret->toString() : QStringLiteral("no declaration found"));)
     return ret;
 }
 
@@ -253,7 +253,7 @@ void ExpressionVisitor::visitClosure(ClosureAst* node)
         DUChainWriteLocker lock;
         forever {
             DeclarationPointer found;
-            foreach(Declaration* dec, m_currentContext->findDeclarations(identifierForNode(it->element->variable))) {
+            for(Declaration* dec : m_currentContext->findDeclarations(identifierForNode(it->element->variable))) {
                 if (dec->kind() == Declaration::Instance) {
                     found = dec;
                     break;
@@ -341,7 +341,7 @@ void ExpressionVisitor::visitFunctionCall(FunctionCallAst* node)
             //global function call foo();
             const QualifiedIdentifier id = identifierForNamespace(node->stringFunctionNameOrClass, m_editor);
             DeclarationPointer dec = findDeclarationImport(FunctionDeclarationType, id);
-            ifDebug(qCDebug(DUCHAIN) << "function call of" << (dec ? dec->toString() : QString("function not found"));)
+            ifDebug(qCDebug(DUCHAIN) << "function call of" << (dec ? dec->toString() : QStringLiteral("function not found"));)
             m_result.setDeclaration(dec);
             usingDeclaration(node->stringFunctionNameOrClass->namespaceNameSequence->back()->element, dec);
             buildNamespaceUses(node->stringFunctionNameOrClass, id);
@@ -361,7 +361,7 @@ void ExpressionVisitor::visitFunctionCall(FunctionCallAst* node)
 ///TODO: DUContext pointer?
 DUContext* ExpressionVisitor::findClassContext(IdentifierAst* className)
 {
-    DUContext* context = 0;
+    DUContext *context = nullptr;
     DeclarationPointer declaration = findDeclarationImport(ClassDeclarationType, className);
     usingDeclaration(className, declaration);
     if (declaration) {
@@ -377,7 +377,7 @@ DUContext* ExpressionVisitor::findClassContext(IdentifierAst* className)
 ///TODO: DUContext pointer?
 DUContext* ExpressionVisitor::findClassContext(NamespacedIdentifierAst* className)
 {
-    DUContext* context = 0;
+    DUContext *context = nullptr;
     const QualifiedIdentifier id = identifierForNamespace(className, m_editor);
     DeclarationPointer declaration = findDeclarationImport(ClassDeclarationType, id);
     usingDeclaration(className->namespaceNameSequence->back()->element, declaration);
@@ -464,7 +464,7 @@ void ExpressionVisitor::visitScalar(ScalarAst *node)
 
     if (!m_inDefine && node->commonScalar && node->commonScalar->scalarType == ScalarTypeString) {
         QString str = m_editor->parseSession()->symbol(node->commonScalar);
-        QRegExp exp("^['\"]([A-Za-z0-9_]+)['\"]$");
+        QRegularExpression exp("^['\"]([A-Za-z0-9_]+)['\"]$");
         if (exp.exactMatch(str)) {
             //that *could* be a class name
             QualifiedIdentifier id(exp.cap(1).toLower());
@@ -532,7 +532,7 @@ void ExpressionVisitor::visitEncapsVar(EncapsVarAst *node)
                         }
                     }
                     if (ctx) {
-                        foreach( Declaration* pdec, ctx->findDeclarations(identifierForNode(node->propertyIdentifier)) ) {
+                        for(Declaration *pdec : ctx->findDeclarations(identifierForNode(node->propertyIdentifier)) ) {
                             if ( !pdec->isFunctionDeclaration() ) {
                                 foundDec = pdec;
                                 break;
@@ -550,7 +550,7 @@ void ExpressionVisitor::visitEncapsVar(EncapsVarAst *node)
 void ExpressionVisitor::visitVariableProperty(VariablePropertyAst *node)
 {
     ifDebug(qCDebug(DUCHAIN) << "node:" << m_editor->parseSession()->symbol(node)
-        << (node->isFunctionCall != -1 ? QString("is function call") : QString("is no function call"));)
+        << (node->isFunctionCall != -1 ? QStringLiteral("is function call") : QStringLiteral("is no function call"));)
     if (node->objectProperty && node->objectProperty->objectDimList) {
         //handle $foo->bar() and $foo->baz, $foo is m_result.type()
 
@@ -576,7 +576,7 @@ void ExpressionVisitor::visitVariableProperty(VariablePropertyAst *node)
                     ifDebug(qCDebug(DUCHAIN) << "property id:" << propertyId.toString();)
 
                     QList<Declaration*> decs;
-                    foreach ( Declaration* dec, context->findDeclarations(propertyId) ) {
+                    for(Declaration *dec : context->findDeclarations(propertyId) ) {
                         if ( node->isFunctionCall != -1 ) {
                             if ( dec->isFunctionDeclaration() ) {
                                 decs << dec;
