@@ -11,7 +11,8 @@
 // local includes
 #include "codedocument.h"
 #include "codegenfactory.h"
-#include "uml.h"
+#include "debug_utils.h"
+#include "umlapp.h"
 
 // qt/kde includes
 #include <QXmlStreamWriter>
