@@ -9,15 +9,15 @@
 #include "codeclassfield.h"
 
 // app includes
-#include "attribute.h"
-#include "association.h"
+#include "umlattribute.h"
+#include "umlassociation.h"
 #include "classifiercodedocument.h"
 #include "codegenerator.h"
 #include "codegenerators/codegenfactory.h"
 #include "debug_utils.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QRegularExpression>
