@@ -10,12 +10,12 @@
 #include "codegenfactory.h"
 
 // app includes
-#include "attribute.h"
+#include "umlattribute.h"
 #include "codegenerator.h"
 #include "debug_utils.h"
 #include "optionstate.h"
-#include "operation.h"
-#include "uml.h"
+#include "umloperation.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlrole.h"
 
