@@ -11,7 +11,7 @@
 // local includes
 #include "classifiercodedocument.h"
 #include "debug_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 
