@@ -10,7 +10,7 @@
 
 // app includes
 #include "cppcodegenerationpolicypage.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umbrellosettings.h"
 #include "optionstate.h"
 
