@@ -16,13 +16,12 @@
 #include "codegen_utils.h"
 #include "codeviewerdialog.h"
 #include "codedocumentlist.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <kconfig.h>
 
 // qt includes
-#include <QRegExp>
 
 const bool CPPCodeGenerator::DEFAULT_BUILD_MAKEFILE = false;
 
@@ -239,7 +238,7 @@ void CPPCodeGenerator::writeCodeToFile(UMLClassifierList & concepts)
 {
     CodeDocumentList docs;
 
-    foreach (UMLClassifier* classifier, concepts) {
+    for(UMLClassifier* classifier : concepts) {
         CodeDocument * doc = findCodeDocumentByClassifier(classifier);
         if(doc)
             docs.append(doc);
@@ -304,7 +303,7 @@ void CPPCodeGenerator::initFromParentDocument()
     // Walk through the document converting classifiers into
     // classifier code documents as needed (e.g only if doesn't exist)
     UMLClassifierList concepts = UMLApp::app()->document()->classesAndInterfaces();
-    foreach (UMLClassifier* c, concepts) {
+    for(UMLClassifier* c : concepts) {
         // Doesn't exist? Then build one.
         CodeDocument * codeDoc = findCodeDocumentByClassifier(c);
         if (!codeDoc)
