@@ -9,7 +9,7 @@
 #include "cppheadercodeaccessormethod.h"
 
 // local includes
-#include "attribute.h"
+#include "umlattribute.h"
 #include "classifiercodedocument.h"
 #include "cppcodegenerator.h"
 #include "cppsourcecodedocument.h"
@@ -19,7 +19,7 @@
 #include "debug_utils.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 CPPHeaderCodeAccessorMethod::CPPHeaderCodeAccessorMethod(CodeClassField * field, CodeAccessorMethod::AccessorType type)
   : CodeAccessorMethod(field)
