@@ -5,13 +5,13 @@
 
 #include "csharpwriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "folder.h"
-#include "operation.h"
-#include "uml.h"
+#include "umlfolder.h"
+#include "umloperation.h"
+#include "umlapp.h"
 #include "umldoc.h"
 
 #include <QRegularExpression>
@@ -346,7 +346,7 @@ void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
     bool generateErrorStub = true;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation* op :  opl) {
         switch (op->visibility()) {
           case Uml::Visibility::Public:
@@ -414,7 +414,7 @@ void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTex
     for(UMLClassifier* obj : *superclasses) {
         if (!obj->isInterface() && obj->hasAbstractOps()) {
             // collect abstract ops
-            UMLOperationList opl(obj->getOpList());
+            UMLOperationList opl(obj->getOperationsList());
             for(UMLOperation* op : opl) {
                 if (op->isAbstract()) {
                     opabstract.append(op);
@@ -456,7 +456,7 @@ void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAs
             continue;
 
         // collect operations of one realization
-        UMLOperationList opreal = real->getOpList();
+        UMLOperationList opreal = real->getOperationsList();
 
         // write realizations
         cs << m_endl << m_container_indent << m_indentation << "#region " << real->name() << " members" << m_endl << m_endl;
@@ -485,7 +485,7 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
                                  bool generateErrorStub /* = false */)
 {
     for(UMLOperation* op : opList) {
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
 
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
