@@ -6,7 +6,7 @@
 #ifndef CSHARPWRITER_H
 #define CSHARPWRITER_H
 
-#include "classifierlistitem.h"
+#include "umlclassifierlistitem.h"
 #include "simplecodegenerator.h"
 #include "umlassociationlist.h"
 #include "umlattributelist.h"
