@@ -11,9 +11,9 @@
 #include "dclassifiercodedocument.h"
 #include "dcodegenerationpolicy.h"
 #include "codegenerator.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "debug_utils.h"
 
 /**
