@@ -1,13 +1,9 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2007 Jari-Matti Mäkelä <jmjm@iki.fi>
+    SPDX-FileCopyrightText: 2008-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "dcodegenerationpolicy.h"
@@ -16,7 +12,7 @@
 // app includes
 #include "dcodegenerationpolicypage.h"
 #include "dcodegenerator.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umbrellosettings.h"
 #include "optionstate.h"
 
@@ -174,4 +170,3 @@ void DCodeGenerationPolicy::init()
     blockSignals(false);
 }
 
-#include "dcodegenerationpolicy.moc"
