@@ -5,22 +5,21 @@
 
 #include "pascalwriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
-#include "classifierlistitem.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
+#include "umlclassifierlistitem.h"
 #include "debug_utils.h"
-#include "enum.h"
-#include "folder.h"
-#include "operation.h"
-#include "template.h"
-#include "uml.h"
+#include "umlenum.h"
+#include "umlfolder.h"
+#include "umloperation.h"
+#include "umltemplate.h"
+#include "umlapp.h"
 #include "umlclassifierlistitemlist.h"
 #include "umldoc.h"
 #include "umltemplatelist.h"
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QFile>
 #include <QRegularExpression>
@@ -281,7 +280,7 @@ void PascalWriter::writeClass(UMLClassifier *c)
     //bool haveAttrs = (isClass && atl.count());
 
     // Generate public operations.
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     UMLOperationList oppub;
 
     for(UMLOperation* op : opl) {
@@ -352,7 +351,7 @@ void PascalWriter::writeOperation(UMLOperation *op, QTextStream &pas, bool is_co
         pas << "// TODO: generate status method " << op->name() << m_endl;
         return;
     }
-    UMLAttributeList atl = op->getParmList();
+    UMLAttributeList atl = op->getParameterList();
     QString rettype = op->getTypeName();
     bool use_procedure = (rettype.isEmpty() || rettype == QStringLiteral("void"));
 
