@@ -7,13 +7,13 @@
 
 #include "rubycodeclassfielddeclarationblock.h"
 
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "codegenerator.h"
 #include "rubycodeclassfield.h"
 #include "rubyclassifiercodedocument.h"
 #include "rubycodegenerationpolicy.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 /**
  * Constructor.
