@@ -32,7 +32,7 @@ public:
     virtual void setDefaults(CodeGenPolicyExt * defaults, bool emitUpdateSignal = true);
     virtual void setDefaults(bool emitUpdateSignal = true);
 
-    CodeGenerationPolicyPage * createPage (QWidget *parent = 0, const char * name = 0);
+    CodeGenerationPolicyPage   *createPage (QWidget *parent = nullptr, const char *name = nullptr);
 
 private:
 
