@@ -11,15 +11,15 @@
 // app includes
 #include "overwritedialog.h"
 #include "model_utils.h"
-#include "attribute.h"
+#include "umlattribute.h"
 #include "umloperationlist.h"
 #include "umlattributelist.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "codedocument.h"
 #include "codegenerationpolicy.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <KLocalizedString>
@@ -250,7 +250,7 @@ bool SimpleCodeGenerator::hasDefaultValueAttr(UMLClassifier *c)
  */
 bool SimpleCodeGenerator::hasAbstractOps(UMLClassifier *c)
 {
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation* op : opl) {
         if (op->isAbstract())
             return true;
