@@ -5,9 +5,9 @@
 
 #include "mysqlwriter.h"
 
-#include "entity.h"
-#include "entityattribute.h"
-#include "foreignkeyconstraint.h"
+#include "umlentity.h"
+#include "umlentityattribute.h"
+#include "umlforeignkeyconstraint.h"
 #include "umlclassifierlistitemlist.h"
 #include "umlentityattributelist.h"
 
