@@ -11,13 +11,12 @@
 #include "debug_utils.h"
 #include "icon_utils.h"
 #include "objectwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlobject.h"
 #include "umlview.h"
 
 // kde includes
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QFrame>
