@@ -9,10 +9,10 @@
 #include "codeeditor.h"
 
 // local includes
-#include "attribute.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlrole.h"
 
