@@ -20,16 +20,16 @@ class AutoLayoutOptionPage : public DialogPageBase, private Ui::AutoLayoutOption
 {
     Q_OBJECT
 public:
-    explicit AutoLayoutOptionPage(QWidget* parent = 0);
+    explicit AutoLayoutOptionPage(QWidget *parent = nullptr);
     virtual ~AutoLayoutOptionPage();
 
     void setDefaults();
     void apply();
 
-signals:
+Q_SIGNALS:
     void applyClicked();
 
-protected slots:
+protected Q_SLOTS:
     void slotAutoDotPathCBClicked(bool value);
 
 };
