@@ -6,21 +6,21 @@
 #include "classifierlistpage.h"
 
 #include "basictypes.h"
-#include "classifierlistitem.h"
+#include "umlclassifierlistitem.h"
 #include "codetextedit.h"
 #define DBG_SRC QStringLiteral("ClassifierListPage")
 #include "debug_utils.h"
 #include "umldoc.h"
-#include "uml.h"  // only needed for log{Warn,Error}
-#include "classifier.h"
-#include "enum.h"
-#include "entity.h"
-#include "attribute.h"
+#include "umlapp.h"  // only needed for log{Warn,Error}
+#include "umlclassifier.h"
+#include "umlenum.h"
+#include "umlentity.h"
+#include "umlattribute.h"
 #include "dialogspopupmenu.h"
-#include "operation.h"
-#include "template.h"
-#include "enumliteral.h"
-#include "entityattribute.h"
+#include "umloperation.h"
+#include "umltemplate.h"
+#include "umlenumliteral.h"
+#include "umlentityattribute.h"
 #include "object_factory.h"
 
 #include <KLocalizedString>
@@ -526,9 +526,9 @@ void ClassifierListPage::printItemList(const QString &prologue)
     UMLClassifierListItemList itemList = getItemList();
     for (UMLClassifierListItemListIt it(itemList); it.hasNext();) {
         item = it.next();
-        buf.append(' ' + item->getName());
+        buf.append(QLatin1Char(' ') + item->getTypeName());
     }
-    logDebug1("%1 %2", prologue, buf);
+    logDebug2("%1 %2", prologue, buf);
 #else
     Q_UNUSED(prologue);
 #endif
