@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -13,11 +13,6 @@
 
 // kde includes
 #include <KComboBox>
-#if QT_VERSION < 0x050000
-#include <KDialog>
-#include <KIntSpinBox>
-#endif
-#include <KLineEdit>
 #include <KLocalizedString>
 
 // qt includes
@@ -25,11 +20,10 @@
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
+#include <QLineEdit>
 #include <QPushButton>
 #include <QRadioButton>
-#if QT_VERSION >= 0x050000
 #include <QSpinBox>
-#endif
 
 /**
  * Constructor.
@@ -39,12 +33,8 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
   : DialogPageBase(parent)
 {
     Settings::OptionState &optionState = Settings::optionState();
-#if QT_VERSION >= 0x050000
-    int spacingHint = 2;
-#else
-    int spacingHint = static_cast<KDialog*>(parent)->spacingHint();
-#endif
-
+    int spacingHint = Dialog_Utils::spacingHint();
+    int margin = fontMetrics().height();
     QVBoxLayout *topLayout = new QVBoxLayout(this);
 
     // Set up undo setting
@@ -53,7 +43,7 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
 
     QGridLayout * miscLayout = new QGridLayout(m_GeneralWidgets.miscGB);
     miscLayout->setSpacing(spacingHint);
-    miscLayout->setMargin(fontMetrics().height());
+    miscLayout->setContentsMargins(margin, margin, margin, margin);
 
     m_GeneralWidgets.undoCB = new QCheckBox(i18n("Enable undo"), m_GeneralWidgets.miscGB);
     m_GeneralWidgets.undoCB->setChecked(optionState.generalState.undo);
@@ -78,10 +68,10 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
     //setup autosave settings
     m_GeneralWidgets.autosaveGB = new QGroupBox(i18n("Autosave"));
     topLayout->addWidget(m_GeneralWidgets.autosaveGB);
-
+    
     QGridLayout * autosaveLayout = new QGridLayout(m_GeneralWidgets.autosaveGB);
     autosaveLayout->setSpacing(spacingHint);
-    autosaveLayout->setMargin(fontMetrics().height());
+    autosaveLayout->setContentsMargins(margin, margin, margin, margin);
 
     m_GeneralWidgets.autosaveCB = new QCheckBox(i18n("E&nable autosave"), m_GeneralWidgets.autosaveGB);
     m_GeneralWidgets.autosaveCB->setChecked(optionState.generalState.autosave);
@@ -90,14 +80,10 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
     m_GeneralWidgets.autosaveL = new QLabel(i18n("Select auto-save time interval (mins):"), m_GeneralWidgets.autosaveGB);
     autosaveLayout->addWidget(m_GeneralWidgets.autosaveL, 1, 0);
 
-#if QT_VERSION >= 0x050000
     m_GeneralWidgets.timeISB = new QSpinBox(m_GeneralWidgets.autosaveGB);
     m_GeneralWidgets.timeISB->setRange(1, 600);
     m_GeneralWidgets.timeISB->setSingleStep(1);
     m_GeneralWidgets.timeISB->setValue(optionState.generalState.autosavetime);
-#else
-    m_GeneralWidgets.timeISB = new KIntSpinBox(1, 600, 1, optionState.generalState.autosavetime, m_GeneralWidgets.autosaveGB);
-#endif
     m_GeneralWidgets.timeISB->setEnabled(optionState.generalState.autosave);
     autosaveLayout->addWidget(m_GeneralWidgets.timeISB, 1, 1);
 
@@ -120,8 +106,7 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
     topLayout->addWidget(m_GeneralWidgets.startupGB);
 
     QGridLayout * startupLayout = new QGridLayout(m_GeneralWidgets.startupGB);
-    startupLayout->setSpacing(spacingHint);
-    startupLayout->setMargin(fontMetrics().height());
+    startupLayout->setSpacing(Dialog_Utils::spacingHint());
 
     m_GeneralWidgets.loadlastCB = new QCheckBox(i18n("&Load last project"), m_GeneralWidgets.startupGB);
     m_GeneralWidgets.loadlastCB->setChecked(optionState.generalState.loadlast);
@@ -131,9 +116,6 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
     startupLayout->addWidget(m_GeneralWidgets.startL, 1, 0);
 
     m_GeneralWidgets.diagramKB = new KComboBox(m_GeneralWidgets.startupGB);
-#if QT_VERSION < 0x050000
-    m_GeneralWidgets.diagramKB->setCompletionMode(KGlobalSettings::CompletionPopup);
-#endif
     startupLayout->addWidget(m_GeneralWidgets.diagramKB, 1, 1);
 
     // start at 1 because we don't allow No Diagram any more
@@ -151,9 +133,6 @@ GeneralOptionPage::GeneralOptionPage(QWidget* parent)
     startupLayout->addWidget(m_GeneralWidgets.defaultLanguageL, 2, 0);
 
     m_GeneralWidgets.languageKB = new KComboBox(m_GeneralWidgets.startupGB);
-#if QT_VERSION < 0x050000
-    m_GeneralWidgets.languageKB->setCompletionMode(KGlobalSettings::CompletionPopup);
-#endif
     startupLayout->addWidget(m_GeneralWidgets.languageKB, 2, 1);
 
     int indexCounter = 0;
@@ -207,7 +186,7 @@ void GeneralOptionPage::apply()
     optionState.generalState.loadlast = m_GeneralWidgets.loadlastCB->isChecked();
     optionState.generalState.diagram  = Uml::DiagramType::fromInt(m_GeneralWidgets.diagramKB->currentIndex() + 1);
     optionState.generalState.defaultLanguage = Uml::ProgrammingLanguage::fromInt(m_GeneralWidgets.languageKB->currentIndex());
-    emit applyClicked();
+    Q_EMIT applyClicked();
 }
 
 /**
