@@ -7,19 +7,19 @@
 #include "parameterpropertiesdialog.h"
 
 // local includes
-#include "attribute.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "documentationwidget.h"
 #include "defaultvaluewidget.h"
 #include "umldatatypewidget.h"
 #include "umlstereotypewidget.h"
 #include "umltemplatelist.h"
-#include "template.h"
+#include "umltemplate.h"
 #include "umldoc.h"
 #include "dialog_utils.h"
 #include "object_factory.h"
-#include "stereotype.h"
+#include "umlstereotype.h"
 
 // kde includes
 #include <KComboBox>
