@@ -7,12 +7,12 @@
 #include "umlattributedialog.h"
 
 // app includes
-#include "attribute.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "documentationwidget.h"
-#include "template.h"
+#include "umltemplate.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldatatypewidget.h"
 #include "umlstereotypewidget.h"
 #include "visibilityenumwidget.h"
