@@ -5,9 +5,9 @@
 
 #include "umlcheckconstraintdialog.h"
 
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
-#include "checkconstraint.h"
+#include "umlcheckconstraint.h"
 
 // kde includes
 #include <KLocalizedString>
