@@ -7,10 +7,10 @@
 #include "umlentityattributedialog.h"
 
 // app includes
-#include "entityattribute.h"
-#include "classifier.h"
+#include "umlentityattribute.h"
+#include "umlclassifier.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldatatypewidget.h"
 #include "defaultvaluewidget.h"
 #include "umlstereotypewidget.h"
