@@ -9,11 +9,11 @@
 #include "umlenumliteraldialog.h"
 
 // app includes
-#include "enumliteral.h"
-#include "classifier.h"
+#include "umlenumliteral.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "dialog_utils.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 // kde includes
 #include <klineedit.h>
