@@ -7,7 +7,7 @@
 
 #include "debug_utils.h"
 #include "file_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "xhtmlgenerator.h"
 
