@@ -10,13 +10,13 @@
 #include "activitywidget.h"
 #include "associationline.h"
 #include "associationwidget.h"
-#include "category.h"
-#include "classifier.h"
+#include "umlcategory.h"
+#include "umlclassifier.h"
 #include "classifierwidget.h"
 #include "combinedfragmentwidget.h"
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
-#include "folder.h"
+#include "umlfolder.h"
 #include "forkjoinwidget.h"
 #include "layoutgenerator.h"
 #include "model_utils.h"
@@ -27,7 +27,7 @@
 #include "preconditionwidget.h"
 #include "signalwidget.h"
 #include "statewidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
