@@ -7,7 +7,7 @@
 
 // app includes
 #include "models/objectsmodel.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlview.h"
 
@@ -20,8 +20,6 @@
 #include <QSortFilterProxyModel>
 #include <QtDebug>
 
-Q_DECLARE_METATYPE(UMLObject*);
-
 ObjectsWindow::ObjectsWindow(const QString &title, QWidget *parent)
   : QDockWidget(title, parent)
 {
