@@ -7,13 +7,13 @@
 #include "umlrole.h"
 
 // local includes
-#include "association.h"
+#include "umlassociation.h"
 #include "debug_utils.h"
 #include "model_utils.h"
 #include "optionstate.h"
 #include "umldoc.h"
 #include "umlroledialog.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QPointer>
