@@ -10,18 +10,18 @@
 #include "floatingtextwidget.h"
 #include "associationwidget.h"
 #include "associationline.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "cmds.h"
 #include "debug_utils.h"
 #include "diagram_utils.h"
 #include "dialog_utils.h"
-#include "instance.h"
+#include "umlinstance.h"
 #include "listpopupmenu.h"
 #include "object_factory.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "optionstate.h"
-#include "template.h"
-#include "uml.h"
+#include "umltemplate.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlview.h"
 #include "widget_utils.h"
@@ -632,7 +632,7 @@ QSizeF ClassifierWidget::calculateSize(bool withExtensions /* = true */) const
         if (numOps > 0) {
             height += numOps * fontHeight;
             // ... width
-            UMLOperationList list(umlc->getOpList());
+            UMLOperationList list(umlc->getOperationsList());
             for(UMLOperation* op : list) {
                       if (visualProperty(ShowPublicOnly) && op->visibility() != Uml::Visibility::Public)
                     continue;
