@@ -10,7 +10,7 @@
 #include "debug_utils.h"
 #include "dialog_utils.h"
 #include "listpopupmenu.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
@@ -195,7 +195,7 @@ QSizeF CombinedFragmentWidget::minimumSize() const
     int width = 10, height = 10;
     const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
     const int fontHeight  = fm.lineSpacing();
-    const int textWidth = fm.width(name());
+    const int textWidth = fm.horizontalAdvance(name());
     height = fontHeight;
     width = textWidth + 60 > defaultWidth ? textWidth + 60: defaultWidth;
     if (m_CombinedFragment == Loop)
@@ -308,7 +308,7 @@ void CombinedFragmentWidget::askNameForWidgetType(UMLWidget* &targetWidget, cons
     } else {
         targetWidget->cleanup();
         delete targetWidget;
-        targetWidget = 0;
+        targetWidget = nullptr;
     }
 }
 
@@ -383,7 +383,7 @@ void CombinedFragmentWidget::removeDashLine(FloatingDashLineWidget *line)
  */
 void CombinedFragmentWidget::cleanup()
 {
-  foreach (FloatingDashLineWidget* w, m_dashLines)
+  for(FloatingDashLineWidget* w : m_dashLines)
   {
     if (!w->isSelected()) {
       // no need to make this undoable, since the dashlines will be
@@ -503,7 +503,7 @@ QPainterPath CombinedFragmentWidget::shape() const
     qreal lw = m_labelWidth + r;
     qreal lh = labelHeight + r;
     if (m_CombinedFragment == Alt) {
-        const int textWidth = fm.width(name() + QStringLiteral("[]"));
+        const int textWidth = fm.horizontalAdvance(name() + QStringLiteral("[]"));
         lh += fontHeight;
         if (lw < textWidth)
             lw = textWidth + r;
