@@ -36,7 +36,7 @@ public:
     explicit ObjectNodeWidget(UMLScene * scene, ObjectNodeType objectNodeType = Normal, Uml::ID::Type id = Uml::ID::None);
     virtual ~ObjectNodeWidget();
 
-    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = nullptr);
 
     ObjectNodeType objectNodeType() const;
     static ObjectNodeType toObjectNodeType(const QString& type);
@@ -58,7 +58,7 @@ public:
 protected:
     QSizeF minimumSize() const;
 
-public slots:
+public Q_SLOTS:
     void slotMenuSelection(QAction* action);
     void slotOk();
 
