@@ -8,54 +8,54 @@
 
 // app includes
 #include "activitywidget.h"
-#include "actor.h"
+#include "umlactor.h"
 #include "actorwidget.h"
-#include "artifact.h"
+#include "umlartifact.h"
 #include "artifactwidget.h"
 #include "associationwidget.h"
 #include "boxwidget.h"
-#include "category.h"
+#include "umlcategory.h"
 #include "categorywidget.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "classifierwidget.h"
 #include "cmds.h"
 #include "combinedfragmentwidget.h"
-#include "component.h"
+#include "umlcomponent.h"
 #include "componentwidget.h"
 #include "datatypewidget.h"
 #define DBG_SRC QStringLiteral("Widget_Factory")
 #include "debug_utils.h"
-#include "entity.h"
+#include "umlentity.h"
 #include "entitywidget.h"
-#include "enum.h"
+#include "umlenum.h"
 #include "enumwidget.h"
-#include "instance.h"
+#include "umlinstance.h"
 #include "floatingdashlinewidget.h"
 #include "floatingtextwidget.h"
-#include "folder.h"
+#include "umlfolder.h"
 #include "forkjoinwidget.h"
 #include "interfacewidget.h"
 #include "messagewidget.h"
-#include "node.h"
+#include "umlnode.h"
 #include "nodewidget.h"
 #include "notewidget.h"
 #include "object_factory.h"
 #include "objectnodewidget.h"
 #include "objectwidget.h"
-#include "package.h"
+#include "umlpackage.h"
 #include "packagewidget.h"
 #include "pinwidget.h"
-#include "port.h"
+#include "umlport.h"
 #include "portwidget.h"
 #include "preconditionwidget.h"
 #include "regionwidget.h"
 #include "signalwidget.h"
 #include "statewidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
-#include "usecase.h"
+#include "umlusecase.h"
 #include "usecasewidget.h"
 
 DEBUG_REGISTER(Widget_Factory)
