@@ -6,9 +6,9 @@
 
 #include "testpackage.h"
 
-#include "classifier.h"
-#include "package.h"
-#include "stereotype.h"
+#include "umlclassifier.h"
+#include "umlpackage.h"
+#include "umlstereotype.h"
 
 void TestPackage::test_appendClassesAndInterfaces()
 {
