@@ -12,7 +12,7 @@
 class TestPreconditionWidget : public TestBase
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void test_saveAndLoad();
 };
 
